import re


def admonition_logo(type, line):
    admonition = {
        "note": "🖊️",
        "seealso": "🖊️",
        "abstract": "📝",
        "summary": "📝",
        "tldr": "📝",
        "info": "ℹ️",
        "todo": "ℹ️",
        "tip": "🔥",
        "hint": "🔥",
        "important": "🔥",
        "success": "✨",
        "check": "✨",
        "done": "✨",
        "question": "❓",
        "help": "❓",
        "faq": "❓",
        "warning": "⚠️",
        "caution": "⚠️",
        "attention": "⚠️",
        "failure": "❌",
        "fail": "❌",
        "missing": "❌",
        "danger": "⚡",
        "error": "⚡",
        "bug": "🐛",
        "example": "📌",
        "exemple": "📌",
        "quote": "📋",
        "cite": "📋",
    }
    if type in admonition.keys():
        logo = admonition[type]
    else:
        logo = "[" + type.title() + "]"
    if line == "":
        title = "**" + logo + "**{: .title}"
    else:
        title = "**" + logo + " " + line + "**{: .title}\n"
    return title


def admonition_trad_content(line, type):

    title = line
    if "collapse:" in line:
        title = ""
    elif "icon:" in line:
        title = ""
    elif "color:" in line:
        title = ""
    elif len(line) == 1:
        title = "$~$  \n"
    elif "title:" in line:
        title = admonition_logo(type, line.replace("title:", "").strip())
    return title


def admonition_trad(file_data):
    code_index = 0
    code_dict = {}
    start_list = []
    end_list = []
    for i in range(0, len(file_data)):
        if re.search("[`?!]{3}( ?)ad-(.*)", file_data[i]):
            start = i
            start_list.append(start)
        elif re.match("```", file_data[i]) or re.match("--- admonition", file_data[i]):
            end = i
            end_list.append(end)
    for i, j in zip(start_list, end_list):
        code = {code_index: (i, j)}
        code_index = code_index + 1
        code_dict.update(code)
    for ad, ln in code_dict.items():
        ad_start = ln[0]
        ad_end = ln[1]
        type = re.search("[`!?]{3}( ?)ad-\w+", file_data[ad_start])
        type = re.sub("[`!?]{3}( ?)ad-", "", type.group())
        adm = "b"
        title = ""
        if re.search("[!?]{3} ad-(\w+) (.*)", file_data[ad_start]):
            title = re.search("[!?]{3} ad-(\w+) (.*)", file_data[ad_start])
            adm = "MT"
            title = title.group(2)
        first_block = re.search("ad-(\w+)", file_data[ad_start])
        first_block = "!!!" + first_block.group()
        file_data[ad_start] = re.sub(
            "[`!?]{3}( ?)ad-(.*)", first_block, file_data[ad_start]
        )
        file_data[ad_end] = "  "
        for i in range(ad_start, ad_end):
            file_data[i] = admonition_trad_content(file_data[i], type)
        if adm == "MT":
            if len(title) > 0:
                title_admo = admonition_logo(type, title)
                file_data.insert(ad_start + 1, title_admo)
            else:
                title_admo = admonition_logo(type, "")
                file_data.insert(ad_start + 1, title_admo)
        else:
            converted = [file_data[i] for i in range(ad_start, ad_end)]
            if not any(re.search(".*title.*", line) for line in converted):
                title_admo = admonition_logo(type, "")
                file_data.insert(ad_start + 1, title_admo)
    return file_data



import os
import re
import shutil

import unidecode

from YAFPA.common import global_value as settings

vault = settings.vault
img = settings.img


def get_image(image):
    image = os.path.basename(image)
    for sub, dirs, files in os.walk(vault):
        for file in files:
            filepath = sub + os.sep + file
            if unidecode.unidecode(image) in unidecode.unidecode(file):
                return filepath


def flags_transform(line, flag):
    img_flags = re.search("[\|\+\-](.*)[]{1,2})]", flag)
    if img_flags:
        img_flags = img_flags.group(0)
        img_flags = img_flags.replace("|", "")
        img_flags = img_flags.replace("]", "")
        img_flags = img_flags.replace(")", "")
        img_flags.replace("(", "")
    else:
        img_flags = ""
    link = re.search("(\[{2}|\().*\.(png|jpg|jpeg|gif)", flag)
    final_text = link.group(0)
    final_text = final_text.replace("(", "")
    final_text = final_text.replace("%20", " ")
    final_text = final_text.replace("[", "")
    final_text = final_text.replace("]", "")
    final_text = final_text.replace(")", "")
    final_text = os.path.basename(final_text)
    image_path = get_image(final_text)
    if image_path:
        shutil.copyfile(image_path, f"{img}/{final_text}")
        final_text = f"../assets/img/{final_text}"
        IAL = f"[{img_flags}]({final_text})"
        line = line.replace(flag, IAL)
    return line


def move_img(line):
    flags = re.search("(\[{2}|\().*\.(png|jpg|jpeg|gif)(\|)?(.*)?[-+]?(.*)?\]{2}", line)
    if flags:
        flags = flags.group().split("!")
        if len(flags) > 1:
            for flag in flags:
                line = flags_transform(line, flag)
        else:
            flags = flags[0]
            line = flags_transform(line, flags)
    return line


def excalidraw_convert(line):
    if ".excalidraw" in line:
        # take the png img from excalidraw
        line = line.replace(".excalidraw", ".excalidraw.png")
        line = line.replace(".md", "")
    return line


def convert_no_embed(line):
    final_text = line
    if re.match("\!\[{2}", line) and not re.match("(.*)\.(png|jpg|jpeg|gif)", line):
        final_text = line.replace("!", "")  # remove "!"
        final_text = re.sub("#\^(.*)", "]]", final_text)  # Link to block doesn't work
    return final_text


def transform_link(line, link):
    title = re.search("\[(.*)]", link)
    if title:
        title = title.group(0)
        title = title.replace("[", "")
        title = title.replace("]", "")
    else:
        title = ""
    links = re.search("\((.*)\)", link)
    if links:
        final_text = links.group(1)
        final_text = final_text.replace("%20", " ")
        final_text = final_text.replace(".md", "")
        IAL = f"[[{final_text}\|{title}]]"
        line = line.replace(link, IAL)
    return line


def convert_to_wikilink(line):
    final_text = line
    if re.search("\[(.*)]\((.*)\)", final_text):
        links = re.search("\[(.*)]\((.*)\)", final_text).group().split()
        if len(links) > 1:
            for link in links:
                if not re.search("https?:\/\/", link) or link == "":
                    line = transform_link(line, link)
        else:
            links = links[0]
            if not re.search("https?:\/\/", links):
                line = transform_link(line, links)
    elif re.search("https?:\/\/", final_text):
        link = re.search("<?(.*)?https?:\/\/.*", final_text).group()
        spl = re.split(">", link)
        links = [x for x in spl if re.search("https?:\/\/.*", x)]
        if len(links) > 1:
            for f in links:
                if not "<" in f:
                    line = final_text.replace(f.strip(), f"[{f.strip()}]({f.strip()})")
        else:
            f = links[0]
            if not "<" in f:
                line = final_text.replace(f.strip(), f"[{f.strip()}]({f.strip()})")
    return line


def transluction_note(line):
    # If file (not image) start with "![[" : transluction with rmn-transclude (exclude
    # image from that)
    # Note : Doesn't support partial transluction for the moment ; remove title
    final_text = line
    if (
        re.search("\!\[", line)
        and not re.search("(png|jpg|jpeg|gif)", line)
        and not re.search("https", line)
    ):
        final_text = line.replace("!", "")  # remove "!"
        final_text = re.sub("#(.*)", "]]", final_text)
        final_text = re.sub("\\|(.*)", "]]", final_text)  # remove Alternative title
        final_text = re.sub("]]", "::rmn-transclude]]", final_text)
    return final_text



import os
import re
from datetime import datetime
from pathlib import Path

import frontmatter

from YAFPA.common import global_value as settings

BASEDIR = Path(settings.BASEDIR)
web = settings.web


def remove_frontmatter(meta):
    meta.pop("date", None)
    meta.pop("title", None)
    meta.pop("created", None)
    meta.pop("update", None)
    meta.pop("link", None)
    return meta


def frontmatter_check(filename, folder):
    metadata = open(Path(f"{folder}/{filename}"), "r", encoding="utf-8")
    meta = frontmatter.load(metadata)
    metadata.close()
    final = open(Path(f"{folder}/{filename}"), "w", encoding="utf-8")
    now = datetime.now().strftime("%d-%m-%Y")
    if (not "current" in meta.keys() or meta["current"] != False) or (
        not "update" in meta.keys() or meta["update"] != false
    ):
        if "date" in meta.keys():
            meta["created"] = meta["date"]
        meta["date"] = now
    if not "title" in meta.keys():
        meta["title"] = filename.replace(".md", "")
    update = frontmatter.dumps(meta)
    final.write(update)
    final.close()
    return


def update_frontmatter(file, folder, share=0, link=1):
    metadata = open(file, "r", encoding="utf8")
    meta = frontmatter.load(metadata)
    metadata.close()
    folder_key = str(folder).replace(f"{BASEDIR}", "")
    folder_key = folder_key.replace(os.sep, "")
    folder_key = folder_key.replace("_", "")
    if "tag" in meta.keys():
        tag = meta["tag"]
    elif "tags" in meta.keys():
        tag = meta["tags"]
    else:
        tag = ""
    meta.metadata.pop("tag", None)
    meta.metadata.pop("tags", None)
    with open(file, "w", encoding="utf-8") as f:
        filename = os.path.basename(file)
        filename = filename.replace(".md", "")
        filename = filename.replace(" ", "-")
        clip = f"{web}{folder_key}/{filename}"
        meta["link"] = clip
        update = frontmatter.dumps(meta, sort_keys=False)
        meta = frontmatter.loads(update)
        if link != 1:
            meta.metadata.pop("link", None)
        elif (
            link == 1
            and share == 1
            and ("share" not in meta.keys() or meta["share"] == "false")
        ):
            meta["share"] = "true"
        if tag != "":
            meta["tag"] = tag
        update = frontmatter.dumps(meta, sort_keys=False)
        if re.search(r"\\U\w+", update):
            emojiz = re.search(r"\\U\w+", update)
            emojiz = emojiz.group().strip()
            raw = r"{}".format(emojiz)
            convert_emojiz = (
                raw.encode("ascii")
                .decode("unicode_escape")
                .encode("utf-16", "surrogatepass")
                .decode("utf-16")
            )
            update = re.sub(r'"\\U\w+"', convert_emojiz, update)
        f.write(update)
    return



import re

html = """https://www.google.com"""
html2 = """<a href="https://docs.google.com/document/d/1bGOITC8zoes1RLDj6ybWDtKiszTnBq5jZe1icx6itnI/edit?usp=sharing"> https://www.google.com"""
html3 = """<a href="https://docs.google.com/document/d/1bGOITC8zoes1RLDj6ybWDtKiszTnBq5jZe1icx6itnI/edit?usp=sharing">"""


def testting(html):
    link = re.search("<?(.*)?https?:\/\/.*", html)
    spl = re.split(">", link.group())
    links = [x for x in spl if re.search("https?:\/\/.*", x)]
    print(links)
    line = ""
    if len(links) > 1:
        for f in links:
            print(f)
            if not "<" in f:
                line = html.replace(f.strip(), f"[{f.strip()}]({f.strip()})")
    else:
        f = links[0]
        print(f)
        if not "<" in f:
            line = html.replace(f.strip(), f"[{f.strip()}]({f.strip()})")
        else:
            line = html
    return line


print("1", testting(html))
print("2", testting(html2))
